@@ -12,7 +12,7 @@ from graphql_subscription_manager import SubscriptionManager
 from .const import RESOLUTION_HOURLY, __version__
 
 DEFAULT_TIMEOUT = 15
-DEMO_TOKEN = "d1007ead2dc84a2b82f0de19451c5fb22112f7ae11d19bf2bedb224a003ff74a"
+DEMO_TOKEN = "476c477d8a039529478ebd690d35ddd80e3308ffc49b59c65b142321aee963a4"
 API_ENDPOINT = "https://api.tibber.com/v1-beta/gql"
 SUB_ENDPOINT = "wss://api.tibber.com/v1-beta/gql/subscriptions"
 
@@ -33,14 +33,9 @@ class Tibber:
     ):
         """Initialize the Tibber connection."""
         if websession is None:
-
-            async def _create_session():
-                return aiohttp.ClientSession(
-                    headers={aiohttp.hdrs.USER_AGENT: f"pyTibber/{__version__}"}
-                )
-
-            loop = asyncio.get_event_loop()
-            self.websession = loop.run_until_complete(_create_session())
+            self.websession = aiohttp.ClientSession(
+                headers={aiohttp.hdrs.USER_AGENT: f"pyTibber/{__version__}"}
+            )
         else:
             self.websession = websession
         self._timeout = timeout
@@ -57,18 +52,12 @@ class Tibber:
         """Close the Tibber connection."""
         await self.websession.close()
 
-    def sync_close_connection(self):
-        """Close the Tibber connection."""
-        loop = asyncio.get_event_loop()
-        task = loop.create_task(self.close_connection())
-        loop.run_until_complete(task)
-
     async def rt_connect(self):
         """Start subscription manager for real time data."""
         if self.sub_manager is not None:
             return
         self.sub_manager = SubscriptionManager(
-            "token={}".format(self._access_token), SUB_ENDPOINT
+            f"token={self._access_token}", SUB_ENDPOINT
         )
         self.sub_manager.start()
 
@@ -124,12 +113,6 @@ class Tibber:
             _LOGGER.error("Received non-compatible response %s", errors)
         return result
 
-    def sync_update_info(self, *_):
-        """Update home info."""
-        loop = asyncio.get_event_loop()
-        task = loop.create_task(self.update_info())
-        loop.run_until_complete(task)
-
     async def update_info(self, *_):
         """Update home info async."""
         query = """
@@ -214,6 +197,7 @@ class Tibber:
 
     async def send_notification(self, title, message):
         """Send notification."""
+        # pylint: disable=consider-using-f-string)
         query = """
         mutation{{
           sendPushNotification(input: {{
@@ -262,14 +246,9 @@ class TibberHome:
         self._data = None
         self.last_data_timestamp = None
 
-    def sync_update_info(self):
-        """Update current price info."""
-        loop = asyncio.get_event_loop()
-        task = loop.create_task(self.update_info())
-        loop.run_until_complete(task)
-
     async def update_info(self):
         """Update current price info async."""
+        # pylint: disable=consider-using-f-string)
         query = (
             """
         {
@@ -335,6 +314,7 @@ class TibberHome:
 
     async def update_info_and_price_info(self):
         """Update current price info async."""
+        # pylint: disable=consider-using-f-string)
         query = (
             """
         {
@@ -421,14 +401,9 @@ class TibberHome:
         self.info = await self._tibber_control.execute(query)
         self._process_price_info(self.info)
 
-    def sync_update_current_price_info(self):
-        """Update current price info."""
-        loop = asyncio.get_event_loop()
-        task = loop.create_task(self.update_current_price_info())
-        loop.run_until_complete(task)
-
     async def update_current_price_info(self):
         """Update current price info async."""
+        # pylint: disable=consider-using-f-string)
         query = (
             """
         {
@@ -464,14 +439,9 @@ class TibberHome:
         if price_info:
             self._current_price_info = price_info
 
-    def sync_update_price_info(self):
-        """Update current price info."""
-        loop = asyncio.get_event_loop()
-        task = loop.create_task(self.update_price_info())
-        loop.run_until_complete(task)
-
     async def update_price_info(self):
         """Update price info async."""
+        # pylint: disable=consider-using-f-string)
         query = (
             """
         {
@@ -621,6 +591,7 @@ class TibberHome:
             _LOGGER.error("Already subscribed.")
             return
         await self._tibber_control.rt_connect()
+        # pylint: disable=consider-using-f-string)
         document = (
             """
             subscription{
@@ -676,6 +647,7 @@ class TibberHome:
 
     async def get_historic_data(self, n_data, resolution=RESOLUTION_HOURLY):
         """Get historic data."""
+        # pylint: disable=consider-using-f-string)
         query = """
                 {{
                   viewer {{
@@ -707,13 +679,6 @@ class TibberHome:
         self._data = data["nodes"]
         return self._data
 
-    def sync_get_historic_data(self, n_data, resolution=RESOLUTION_HOURLY):
-        """get historic data."""
-        loop = asyncio.get_event_loop()
-        task = loop.create_task(self.get_historic_data(n_data, resolution))
-        loop.run_until_complete(task)
-        return self._data
-
     def current_price_data(self):
         """get current price."""
         now = dt.datetime.now(self._tibber_control.time_zone)
@@ -772,9 +737,9 @@ class TibberHome:
         if grid_company and "glitre" in grid_company.lower():
             now = now.astimezone(pytz.timezone("Europe/Oslo"))
             if now.month >= 10 or now.month <= 3:
-                grid_price = 41.86 / 100
+                grid_price = 44.99 / 100
             else:
-                grid_price = 39.99 / 100
+                grid_price = 43.11 / 100
             if now.hour >= 22 or now.hour < 6:
                 grid_price -= 12 / 100
             attr["grid_price"] = round(grid_price, 3)
